import { Api } from './api';
import { HttpRequestOptions, TypedEmitter, TypedEvents } from '@ztimson/utils';
import { BehaviorSubject } from 'rxjs';
import { Meta } from './core';
export type Action = Meta & {
    name: string;
    trigger: {
        type: ActionType;
        value: string;
    };
    system?: boolean;
    fn: string;
    notes?: string;
    lastRun?: Date;
    lastRunLength?: number;
    nextRun?: Date;
};
export type ActionResponse = {
    action: string;
    stdout: any[];
    stderr: any[];
    return?: any;
};
export declare enum ActionType {
    'CRON' = 0,
    'EVENT' = 1,
    'DELETE' = 2,
    'GET' = 3,
    'PATCH' = 4,
    'POST' = 5,
    'PUT' = 6
}
export type ActionEvents = TypedEvents & {
    all: (actions: Action[]) => any;
    delete: (id: string) => any;
    read: (action: Action | null) => any;
    update: (action: Action) => any;
    execute: (action: string, resp: any) => any;
};
export declare class Actions extends TypedEmitter<ActionEvents> {
    private readonly api;
    $cache: BehaviorSubject<Action[]>;
    get cache(): Action[];
    set cache(val: Action[]);
    constructor(api: Api | string);
    delete(id: string): Promise<void>;
    all(): Promise<Action[]>;
    read(id: string, reload?: boolean): Promise<Action | null>;
    run<T>(path: string, opts?: HttpRequestOptions): import('@ztimson/utils').PromiseProgress<any>;
    runById(action: string | Action, opts?: HttpRequestOptions): import('@ztimson/utils').PromiseProgress<any>;
    update(action: Action): Promise<Action>;
}
//# sourceMappingURL=actions.d.ts.map