import { Api } from './api';
import { Meta } from './core';
import { TypedEmitter, TypedEvents } from '@ztimson/utils';
export type Document<T> = Meta & T;
export type RawQuery = {
    operand: 'delete' | 'deleteOne' | 'find' | 'findOne' | 'insert' | 'replaceOne' | 'update' | 'updateOne';
    filter?: any;
    data?: any;
    options?: any;
    count?: boolean;
};
/**
 * Recursive type for defining data schema: [path sagment, exists, children]
 */
export type TreeNode = [string, boolean, TreeNode[]];
export type DataEvents = TypedEvents & {
    create: (collection: string, document: any) => any;
    read: (collection: string, documents: any | any[]) => any;
    update: (collection: string, document: any) => any;
    delete: (collection: string, document: string) => any;
    raw: (collection: string, query: RawQuery, response: any) => any;
};
export declare class Data extends TypedEmitter<DataEvents> {
    private readonly api;
    constructor(api: Api | string);
    create<T>(collection: string, document: Document<T>): Promise<Document<T>>;
    read<T extends Meta>(collection: string): Promise<T[]>;
    read<T extends Meta>(collection: string, document: string): Promise<T>;
    update<T>(collection: string, document: Document<T>, append?: boolean): Promise<Document<T>>;
    delete(collection: string, document: string): Promise<void>;
    raw<T>(collection: string, query: RawQuery): Promise<Document<T>>;
}
//# sourceMappingURL=data.d.ts.map