import { Api } from './api';
import { Meta } from './core';
import { PromiseProgress, TypedEmitter, TypedEvents, HttpRequestOptions } from '@ztimson/utils';
export type DirMeta = {
    children: (DirMeta | FileMeta)[];
    path: string;
    name: string;
    mime: 'directory';
    size: number;
};
export type FileMeta = Meta & {
    path: string;
    name: string;
    mime: string;
    size: number;
    missing?: boolean;
};
export type StorageEvents = TypedEvents & {
    copy: (path: string, response: DirMeta | FileMeta) => any;
    delete: (path: string) => any;
    download: (path: string, data: Blob) => any;
    list: (path: string, meta: DirMeta | FileMeta) => any;
    open: (path: string) => any;
    mkdir: (path: string, meta: DirMeta) => any;
    move: (from: string, to: string, meta: DirMeta | FileMeta) => any;
    upload: (files: FileMeta[]) => any;
};
export declare class Storage extends TypedEmitter<StorageEvents> {
    readonly api: Api;
    constructor(api: Api | string);
    copy(path: string): Promise<DirMeta | FileMeta>;
    delete(path: string): Promise<void>;
    download(path: string, opts?: HttpRequestOptions & {
        'downloadAs'?: string;
    }): PromiseProgress<Blob>;
    list(path: string): Promise<DirMeta | FileMeta>;
    open(path: string, target: false): string;
    open(path: string, target?: '_blank' | '_self'): Window | null;
    mkdir(path: string): Promise<DirMeta>;
    move(from: string, to: string): Promise<DirMeta | FileMeta>;
    upload(files?: File | File[] | null, opts?: string | {
        path?: string;
        accept?: string;
        multiple?: boolean;
    }): PromiseProgress<FileMeta[]>;
}
//# sourceMappingURL=storage.d.ts.map